/*
Copyright 2015-2016, Manuel Bichler
WWW: <http://dbai.tuwien.ac.at/proj/lpopt/>

This file is part of lpopt.

lpopt is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

lpopt is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with lpopt.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef STRING_GENERATOR_H_
#define STRING_GENERATOR_H_

#include<string>

using namespace std;

namespace domain
{
  class StringGenerator // has a base string (e.g. "temp") and generates strings like "temp0", "temp0", and so on.
  {
  public:
    StringGenerator(); // base name "temp"
    StringGenerator(string* baseName);
    ~StringGenerator();
    string* get(); // returns new string with next residual
    string* previous(); // returns copy of previously returned temp. predicate
  private:
    string* baseName;
    unsigned long ct;
  };
  
  class StringGeneratorGenerator // has a base string (e.g. "temp") and generates string generators with base strings like "temp0_", "temp1_", and so on.
  {
  public:
    StringGeneratorGenerator(); // base name "temp"
    StringGeneratorGenerator(string* baseName);
    ~StringGeneratorGenerator();
    StringGenerator* get(); // returns new string generator with next residual
    StringGenerator* previous(); // returns prviously returned generator (same object). If get() has not yet been called, returns NULL.
  private:
    string* baseName;
    unsigned long ct;
    StringGenerator* prev;
  };
} // namespace domain

#endif //STRING_GENERATOR_H_
