/*
Copyright 2015-2016, Manuel Bichler
WWW: <http://dbai.tuwien.ac.at/proj/lpopt/>

This file is part of lpopt.

lpopt is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

lpopt is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with lpopt.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <stdexcept>
#include <string>

#include "Driver.h"
#include "scanner.h"

namespace parser {

Driver::Driver(std::istream *stream) : stream(stream), program(NULL)
{
}

Driver::~Driver()
{
}

domain::Program* Driver::parse()
{
	delete program;
	FlexScanner scanner(stream);
	::parser::Parser parser(*this, scanner);
	int res = parser.parse();
	if (res == 0) return program;
	throw std::runtime_error(std::string("Parse error. Parser returned ") + std::to_string(res));
}

void Driver::error(const parser::location& l, const std::string& m)
{
	std::ostringstream ss;
	ss << "Parse error." << std::endl << l << ": " << m;
	throw std::runtime_error(ss.str());
}

} // namespace parser
